#!/bin/bash
#
#    PFGtool, Par File Generation Tool.
#    Copyright (C) 2007, Joakim Soderlund
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License along
#    with this program; if not, write to the Free Software Foundation, Inc.,
#    51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
#
echo " "
echo " >> PFGtool - Version 0.2 <<"
echo " "
if [ "$1" = "" ]; then
	echo "Usage: pfgtool [action] [options]"
	echo " "
	echo "Actions:	x - Extract files from a pfg file."
	echo "		a - Create a pfg file."
	echo "		? - Copy a reference file to the refdb."
	echo "		? - Link a reference file to the refdb."
	echo "		? - Generate a new reference file."
	echo " "
fi

if [ "$1" = "X" -o "$1" = "x" ]; then
	if [ "$2" = "help" -o "$2" = "" ]; then
		echo "Usage: pfgtool x [filename]"
		echo " "
		echo "Extract the files from a pfg file."
		echo "The pfg file is specified by the filename option."
		echo " "
	else
		cd workdir
		tar -xf "../$2"
		for a in `cat input.ref`; do
			if [ -e "../refdb/$a" ]; then
				ln -s ../refdb/$a
			else
				echo "Could not find reference: $a"
				echo " "
				rm ../workdir/*
				exit
			fi
		done
		echo "Please wait... Generating files..."
		par2repair input.par2
		for a in `cat input.ref`; do
			rm ../workdir/$a
		done
		rm ../workdir/input.*
		mv * ../
		cd ..
	fi
fi

if [ "$1" = "A" -o "$1" = "a" ]; then
	if [ "$2" = "help" -o "$2" = "" ]; then
		echo "Usage: pfgtool a [references]"
		echo " "
		echo "Creates a pfg file for the files in the workdir."
		echo "You may specify one to eight reference files."
		echo " "
	else
		cd workdir
		for a in {"$2","$3","$4","$5","$6","$7","$8","$9"}; do
			if [ "$a" != "" ]; then
				echo $a >> input.ref
			fi
		done
		mv input.ref ../input.ref.tmp
		for a in `cat ../input.ref.tmp`; do
			if [ -e "../refdb/$a" ]; then
				ln -s ../refdb/$a
				echo "Added reference: $a"
			else
				echo "Could not find reference: $a"
				echo " "
				rm ../workdir/*
				exit
			fi
		done
		par2create -r0 input *
		mv * ../tmp/
		for a in `cat ../input.ref.tmp`; do
			mv ../tmp/$a ./
		done
		mv ../tmp/input.par2 ./
		pfg_red=`par2verify input.par2 | grep "You need" | cut -d " " -f 3`
		mv ../tmp/* ./
		rm input.par2
		par2create -c$pfg_red input *
		mv ../input.ref.tmp input.ref
		tar -cf ../output.pfg input.*
		rm ../workdir/*
	fi
fi
exit

